@@ -1,6 +1,6 @@
 ###################################################################
 # rdsampsi: sample size calculations for RD designs
-# !version 1.0 23-Aug-2020
+# !version 2.0 17-Dec-2020
 # Authors: Matias Cattaneo, Rocio Titiunik, Gonzalo Vazquez-Bare
 ###################################################################
 
@@ -90,7 +90,7 @@
 #'
 #' @export
 
-rdsampsi = function(data = NULL,
+rdsampsi <- function(data = NULL,
                     cutoff = 0,
                     tau = NULL,
                     alpha = 0.05,
@@ -134,8 +134,8 @@ rdsampsi = function(data = NULL,
   if (!is.null(data)){
     if (ncol(data)<2){stop('Too few variables specified in data')}
     else{
-      Y = data[,1]
-      R = data[,2]
+      Y <- data[,1]
+      R <- data[,2]
     }
   }
 
@@ -147,21 +147,21 @@ rdsampsi = function(data = NULL,
       } else{
         if (sum(nsamples%%1)!=0){stop('sample sizes in nsamples have to be integers')}
         if (min(nsamples)<=0){stop('sample sizes in nsamples have to be >0')}
-        nminus = nsamples[1]
-        n.hnew.l = nsamples[2]
-        n.hnew.r = nsamples[3]
-        nplus = nsamples[4]
+        nminus <- nsamples[1]
+        n.hnew.l <- nsamples[2]
+        nplus <- nsamples[3]
+        n.hnew.r <- nsamples[4]
       }
     }
   }
 
   if (!is.null(samph)){
     if (length(samph)==1){
-      hnew.l = samph
-      hnew.r = samph
+      hnew.l <- samph
+      hnew.r <- samph
     } else if (length(samph)==2){
-      hnew.l = samph[1]
-      hnew.r = samph[2]
+      hnew.l <- samph[1]
+      hnew.r <- samph[2]
     } else{
       stop('samph incorrectly specified')
     }
@@ -170,8 +170,8 @@ rdsampsi = function(data = NULL,
   if (!is.null(bias)){
     if (length(bias)==1){stop('need to specify both Bl and Br')}
     else if (length(bias)==2){
-      bias.l = bias[1]
-      bias.r = bias[2]
+      bias.l <- bias[1]
+      bias.r <- bias[2]
     }
     else {stop('bias incorrectly specified')}
   }
@@ -180,13 +180,13 @@ rdsampsi = function(data = NULL,
     if (min(variance)<=0){stop('variances have to be >0')}
     if (length(variance)==1){stop('need to specify both Vl and Vr')}
     else if (length(variance)==2){
-      vl = variance[1]
-      vr = variance[2]
+      vl <- variance[1]
+      vr <- variance[2]
     }
     else {stop('variance incorrectly specified')}
     if (is.null(data)){
-      vl.cl = vl
-      vr.cl = vr
+      vl.cl <- vl
+      vr.cl <- vr
     }
   }
 
@@ -198,7 +198,7 @@ rdsampsi = function(data = NULL,
     }
   }
 
-  if (is.null(q)){ q = p + 1}
+  if (is.null(q)){ q <- p + 1}
 
 
   #################################################################
@@ -207,62 +207,62 @@ rdsampsi = function(data = NULL,
 
   if (!is.null(data)){
     if (is.null(bias) | is.null(variance)){
-      aux = rdrobust::rdrobust(Y,R,c=cutoff,all=TRUE,covs=covs,covs_drop=covs_drop,deriv=deriv,p=p,q=q,h=h,b=b,rho=rho,cluster=cluster,
+      aux <- rdrobust::rdrobust(Y,R,c=cutoff,all=TRUE,covs=covs,covs_drop=covs_drop,deriv=deriv,p=p,q=q,h=h,b=b,rho=rho,cluster=cluster,
                      kernel=kernel,bwselect=bwselect,vce=vce,scalepar=scalepar,scaleregul=scaleregul,
                      fuzzy=fuzzy,level=level,weights=weights,masspoints=masspoints,bwcheck=bwcheck,bwrestrict=bwrestrict,stdvars=stdvars)
 
-      h.aux = aux$bws
-      h.l = h.aux[1,1]
-      h.r = h.aux[1,2]
-      nh.l = aux$Nh[1]
-      nh.r = aux$Nh[2]
+      h.aux <- aux$bws
+      h.l <- h.aux[1,1]
+      h.r <- h.aux[1,2]
+      nh.l <- aux$Nh[1]
+      nh.r <- aux$Nh[2]
 
       if (is.null(bias)){
-        bias = aux$bias
-        bias.l = bias[1]/(h.l^(1+p-deriv))
-        bias.r = bias[2]/(h.r^(1+p-deriv))
+        bias <- aux$bias
+        bias.l <- bias[1]/(h.l^(1+p-deriv))
+        bias.r <- bias[2]/(h.r^(1+p-deriv))
       }
 
       if (is.null(variance)){
-        VL.CL = aux$V_cl_l
-        VR.CL = aux$V_cl_r
-        VL.RB = aux$V_rb_l
-        VR.RB = aux$V_rb_r
+        VL.CL <- aux$V_cl_l
+        VR.CL <- aux$V_cl_r
+        VL.RB <- aux$V_rb_l
+        VR.RB <- aux$V_rb_r
 
         if (!is.null(cluster)){
-          N = length(table(cluster[!is.na(Y) & !is.na(R)]))
+          N <- length(table(cluster[!is.na(Y) & !is.na(R)]))
         } else{
-          N = sum(!is.na(Y) & !is.na(R))
+          N <- sum(!is.na(Y) & !is.na(R))
         }
-        pos = 1 + deriv
-        vl = N*(h.l^(1+2*deriv))*VL.RB[pos,pos]
-        vr = N*(h.r^(1+2*deriv))*VR.RB[pos,pos]
-        vl.cl = N*(h.l^(1+2*deriv))*VL.CL[pos,pos]
-        vr.cl = N*(h.r^(1+2*deriv))*VR.CL[pos,pos]
+        pos <- 1 + deriv
+        vl <- N*(h.l^(1+2*deriv))*VL.RB[pos,pos]
+        vr <- N*(h.r^(1+2*deriv))*VR.RB[pos,pos]
+        vl.cl <- N*(h.l^(1+2*deriv))*VL.CL[pos,pos]
+        vr.cl <- N*(h.r^(1+2*deriv))*VR.CL[pos,pos]
       }
     }
 
     if (is.null(samph)){
-      hnew.l = h.l
-      hnew.r = h.r
+      hnew.l <- h.l
+      hnew.r <- h.r
     }
 
     if (is.null(vl.cl) | is.null(vr.cl)){
-      vl.cl = vl
-      vr.cl = vr
+      vl.cl <- vl
+      vr.cl <- vr
     }
   }
 
   # Bias adjustment
 
-  bias = bias.r*hnew.r^(1+p-deriv) + bias.l*hnew.l^(1+p-deriv)
+  bias <- bias.r*hnew.r^(1+p-deriv) + bias.l*hnew.l^(1+p-deriv)
 
   # Variance adjustment
 
-  V.rbc = vl/(hnew.l^(1+2*deriv)) + vr/(hnew.r^(1+2*deriv))
-  stilde = sqrt(V.rbc)
-  V.cl = vl.cl/(hnew.l^(1+2*deriv)) + vr.cl/(hnew.r^(1+2*deriv))
-  stilde.cl = sqrt(V.cl)
+  V.rbc <- vl/(hnew.l^(1+2*deriv)) + vr/(hnew.r^(1+2*deriv))
+  stilde <- sqrt(V.rbc)
+  V.cl <- vl.cl/(hnew.l^(1+2*deriv)) + vr.cl/(hnew.r^(1+2*deriv))
+  stilde.cl <- sqrt(V.cl)
 
 
   #################################################################
@@ -271,31 +271,31 @@ rdsampsi = function(data = NULL,
 
   # Critical value
 
-  z = qnorm(1-alpha/2)
+  z <- qnorm(1-alpha/2)
 
   # Set default value of tau
 
   if (is.null(tau)){
-    sd0 = sd(Y[R>=cutoff-hnew.l & R<cutoff],na.rm=TRUE)
-    tau = 0.5*sd0
+    sd0 <- sd(Y[R>=cutoff-hnew.l & R<cutoff],na.rm=TRUE)
+    tau <- 0.5*sd0
   }
 
   # Set initial value for Newton-Raphson
 
   if (is.null(init.cond)){
-    init.cond = sum(!is.na(Y) & !is.na(R))
+    init.cond <- sum(!is.na(Y) & !is.na(R))
   }
 
   # Find m
 
   cat('Calculating sample size...')
 
-  maux = rdpower.powerNR(init.cond,tau,stilde,z,beta)
-  m = maux$m
+  maux <- rdpower.powerNR(init.cond,tau,stilde,z,beta)
+  m <- maux$m
 
   if (all==TRUE){
-    maux1 = rdpower.powerNR(init.cond,tau+bias,stilde.cl,z,beta)
-    m.cl = maux1$m
+    maux1 <- rdpower.powerNR(init.cond,tau+bias,stilde.cl,z,beta)
+    m.cl <- maux1$m
   }
 
   cat('Sample size obtained.')
@@ -303,39 +303,39 @@ rdsampsi = function(data = NULL,
   # Adjust m to find sample sizes
 
   if (is.null(nratio)){
-    nratio = sqrt(vr)/(sqrt(vr)+sqrt(vl))
-    nratio.cl = sqrt(vr.cl)/(sqrt(vr.cl)+sqrt(vl.cl))
+    nratio <- sqrt(vr)/(sqrt(vr)+sqrt(vl))
+    nratio.cl <- sqrt(vr.cl)/(sqrt(vr.cl)+sqrt(vl.cl))
   }
 
   if (!is.null(data)){
     if (!is.null(cluster)){
-      N = length(table(cluster[!is.na(Y)&!is.na(R)]))
-      nplus = length(table(cluster[R>=cutoff & !is.na(Y) & !is.na(R)]))
-      nminus = length(table(cluster[R<cutoff & !is.na(Y) & !is.na(R)]))
-      n.hnew.r = length(table(cluster[R>=cutoff & R<= cutoff + hnew.r & !is.na(Y) & !is.na(R)]))
-      n.hnew.l = length(table(cluster[R<cutoff & R>= cutoff - hnew.l & !is.na(Y) & !is.na(R)]))
+      N <- length(table(cluster[!is.na(Y)&!is.na(R)]))
+      nplus <- length(table(cluster[R>=cutoff & !is.na(Y) & !is.na(R)]))
+      nminus <- length(table(cluster[R<cutoff & !is.na(Y) & !is.na(R)]))
+      n.hnew.r <- length(table(cluster[R>=cutoff & R<= cutoff + hnew.r & !is.na(Y) & !is.na(R)]))
+      n.hnew.l <- length(table(cluster[R<cutoff & R>= cutoff - hnew.l & !is.na(Y) & !is.na(R)]))
     } else{
-      N = sum(!is.na(Y) & !is.na(R))
-      nplus = sum(R>=cutoff & !is.na(Y) & !is.na(R))
-      nminus = sum(R<cutoff & !is.na(Y) & !is.na(R))
-      n.hnew.r = sum(R>=cutoff & R<= cutoff + hnew.r & !is.na(Y) & !is.na(R))
-      n.hnew.l = sum(R<cutoff & R>= cutoff - hnew.l & !is.na(Y) & !is.na(R))
+      N <- sum(!is.na(Y) & !is.na(R))
+      nplus <- sum(R>=cutoff & !is.na(Y) & !is.na(R))
+      nminus <- sum(R<cutoff & !is.na(Y) & !is.na(R))
+      n.hnew.r <- sum(R>=cutoff & R<= cutoff + hnew.r & !is.na(Y) & !is.na(R))
+      n.hnew.l <- sum(R<cutoff & R>= cutoff - hnew.l & !is.na(Y) & !is.na(R))
     }
   }
 
-  denom = nratio*nplus/n.hnew.r + (1-nratio)*nminus/n.hnew.l
-  denom.cl = nratio.cl*nplus/n.hnew.r + (1-nratio.cl)*nminus/n.hnew.l
+  denom <- nratio*nplus/n.hnew.r + (1-nratio)*nminus/n.hnew.l
+  denom.cl <- nratio.cl*nplus/n.hnew.r + (1-nratio.cl)*nminus/n.hnew.l
 
-  M = m/denom
-  Ml = ceiling(M*nratio)
-  Mr = ceiling(M*(1-nratio))
-  M = Ml + Mr
+  M <- m/denom
+  Mr <- ceiling(M*nratio)
+  Ml <- ceiling(M*(1-nratio))
+  M <- Ml + Mr
 
   if (all==TRUE){
-    M.cl = m.cl/denom.cl
-    Ml.cl = ceiling(M.cl*nratio.cl)
-    Mr.cl = ceiling(M.cl*(1-nratio.cl))
-    M.cl = Ml.cl + Mr.cl
+    M.cl <- m.cl/denom.cl
+    Mr.cl <- ceiling(M.cl*nratio.cl)
+    Ml.cl <- ceiling(M.cl*(1-nratio.cl))
+    M.cl <- Ml.cl + Mr.cl
   }
 
   #################################################################
@@ -347,41 +347,36 @@ rdsampsi = function(data = NULL,
     # Left panel
 
     if (!is.null(cluster)){
-      gplus = length(table(cluster[R>=cutoff & !is.na(Y) & !is.na(R)]))
-      gminus = length(table(cluster[R<cutoff & !is.na(Y) & !is.na(R)]))
+      gplus <- length(table(cluster[R>=cutoff & !is.na(Y) & !is.na(R)]))
+      gminus <- length(table(cluster[R<cutoff & !is.na(Y) & !is.na(R)]))
     }
 
-    nplus.disp = sum(R>=cutoff & !is.na(Y) & !is.na(R))
-    nminus.disp = sum(R<cutoff & !is.na(Y) & !is.na(R))
+    nplus.disp <- sum(R>=cutoff & !is.na(Y) & !is.na(R))
+    nminus.disp <- sum(R<cutoff & !is.na(Y) & !is.na(R))
 
     if (is.null(h)){
-      hl = hnew.l
-      hr = hnew.r
+      hl <- hnew.l
+      hr <- hnew.r
     } else{
-      hl = h.l
-      hr = h.r
+      hl <- h.l
+      hr <- h.r
     }
 
-    n.hnew.r.disp = sum(R>=cutoff & R<= cutoff + hr & !is.na(Y) & !is.na(R))
-    n.hnew.l.disp = sum(R<cutoff & R>= cutoff - hl & !is.na(Y) & !is.na(R))
-
-    # if (is.null(h)){
-    #   hl = NA
-    #   hr = NA
-    # }
+    n.hnew.r.disp <- sum(R>=cutoff & R<= cutoff + hr & !is.na(Y) & !is.na(R))
+    n.hnew.l.disp <- sum(R<cutoff & R>= cutoff - hl & !is.na(Y) & !is.na(R))
 
     # Right panel
 
-    N.disp = sum(!is.na(Y) & !is.na(R))
+    N.disp <- sum(!is.na(Y) & !is.na(R))
 
     if (is.null(bias) | is.null(variance)){
-      bwselect = aux$bwselect
-      kernel_type = aux$kernel
-      vce_type = aux$vce
+      bwselect <- aux$bwselect
+      kernel_type <- aux$kernel
+      vce_type <- aux$vce
     } else{
-      bwselect = NA
-      kernel_type = NA
-      vce_type = NA
+      bwselect <- NA
+      kernel_type <- NA
+      vce_type <- NA
     }
 
 
@@ -390,24 +385,24 @@ rdsampsi = function(data = NULL,
     # Left panel
 
     if (!is.null(cluster)){
-      gplus = NA
-      gminus = NA
+      gplus <- NA
+      gminus <- NA
     }
-    nplus.disp = NA
-    nminus.disp = NA
-    n.hnew.l.disp = NA
-    n.hnew.r.disp = NA
+    nplus.disp <- NA
+    nminus.disp <- NA
+    n.hnew.l.disp <- NA
+    n.hnew.r.disp <- NA
 
-    hl = NA
-    hr = NA
-    p = NA
+    hl <- NA
+    hr <- NA
+    p <- NA
 
     # Right panel
 
-    N.disp = NA
-    bwselect = NA
-    kernel_type = NA
-    vce_type = NA
+    N.disp <- NA
+    bwselect <- NA
+    kernel_type <- NA
+    vce_type <- NA
   }
 
 
@@ -434,6 +429,7 @@ rdsampsi = function(data = NULL,
   cat(paste0(format("Sampling BW",        width=22), format(toString(round(hnew.l,3)), width=16), format(toString(round(hnew.r,3)),   width=16))); cat("\n")
   cat("\n\n")
 
+  cat(paste0(rep('=',89),collapse='')); cat('\n')
   cat(paste0(format('Chosen sample sizes',   width=33),
              format('Sample size in window', width=35),
              format('Proportion',            width=15))); cat('\n')
@@ -443,7 +439,7 @@ rdsampsi = function(data = NULL,
              format('[c,c+h]', width=15),
              format('Total',   width=15),
              format('[c,c+h]', width=13))); cat('\n')
-
+  cat(paste0(rep('-',89),collapse='')); cat('\n')
   cat(paste0(format('Robust bias-corrected', width=25),
              format(toString(Ml), width=15),
              format(toString(Mr), width=15),
@@ -457,7 +453,8 @@ rdsampsi = function(data = NULL,
                format(toString(Mr.cl), width=15),
                format(toString(M.cl), width=15),
                format(toString(round(nratio.cl,3)), width=13))); cat('\n')
-  } else {cat('\n\n')}
+    cat(paste0(rep('=',89),collapse='')); cat('\n')
+  } else {cat('\n');cat(paste0(rep('=',89),collapse=''));cat('\n\n')}
 
 
   #################################################################
@@ -466,14 +463,14 @@ rdsampsi = function(data = NULL,
 
   if (plot==TRUE){
 
-    N.plot = sum(!is.na(Y) & !is.na(R))
+    N.plot <- sum(!is.na(Y) & !is.na(R))
 
     if(is.null(graph.range)){
-      left = 0
-      right = N.plot
+      left <- 0
+      right <- N.plot
     } else{
-      left = graph.range[1]
-      right = graph.range[2]
+      left <- graph.range[1]
+      right <- graph.range[2]
     }
 
     plot(function(x) 1 - pnorm(sqrt(x*denom)*tau/stilde+qnorm(1-alpha/2)) + pnorm(sqrt(x*denom)*tau/stilde-qnorm(1-alpha/2)),
@@ -492,7 +489,7 @@ rdsampsi = function(data = NULL,
   # Return values
   #################################################################
 
-  output = list(sampsi.h.tot = M,
+  output <- list(sampsi.h.tot = M,
                 sampsi.h.r = Mr,
                 sampsi.h.l = Ml,
                 sampsi.tot = m,
@@ -512,7 +509,7 @@ rdsampsi = function(data = NULL,
                 init.cond = init.cond,
                 no.iter = maux$iter)
   if (all==TRUE){
-    output = c(output,
+    output <- c(output,
                sampsi.h.tot.cl = M.cl,
                sampsi.h.r.cl = Mr.cl,
                sampsi.h.l.cl = Ml.cl,
